package
Version:
v0.0.0-...-0d6c723
Opens a new window with list of versions in this module.
Published: May 26, 2023
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type AuthUser struct {
UserId string `json:"userId"`
Message string `json:"message"`
}
type Login struct {
AccessToken string `json:"accessToken"`
RefreshToken string `json:"refreshToken"`
ExpiresAt string `json:"expiresAt"`
}
type User struct {
Uid string `json:"uid"`
Name string `json:"name"`
Surname string `json:"surname"`
Email string `json:"email"`
Icon *string `json:"icon"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.